pm4py.algo.transformation.ocel.split\_ocel package
==================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.transformation.ocel.split_ocel.variants

Submodules
----------

pm4py.algo.transformation.ocel.split\_ocel.algorithm module
-----------------------------------------------------------

.. automodule:: pm4py.algo.transformation.ocel.split_ocel.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.transformation.ocel.split_ocel
   :members:
   :undoc-members:
   :show-inheritance:
